(developer.getting_started)=
# Getting started

This section provides a step-by-step guide to help you get started with developing for BEC. Whether you are new to BEC or an experienced developer, this guide will help you set up your development environment, understand the architecture of BEC, and contribute effectively to the project.

```{toctree}
---
maxdepth: 2
hidden: true
---

architecture/
contributing/
install_developer_env/
vscode/
bec_service_config/
bec_plugins/
logs/
tests/
```



